@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
+   Copyright © 1990-2023 Free Software Foundation, Inc.
    François Pinard <pinard@iro.umontreal.ca>, 1990.
 
    This program is free software; you can redistribute it and/or modify it
@@ -85,6 +85,9 @@ static bool touch_option = false;
 /* With strict mapping, all reversibility fallbacks get defeated.  */
 static bool strict_mapping = false;
 
+/* Use iconv if possible. */
+static bool prefer_iconv = false;
+
 /* The following charset name will be ignored, if given.  */
 static const char *ignored_name = NULL;
 
@@ -330,19 +333,18 @@ new_outer(unsigned flags)
 {
   /* Register all modules and build internal tables.  */
 
-  RECODE_OUTER outer = recode_new_outer (flags | RECODE_AUTO_ABORT_FLAG);
+  RECODE_OUTER outer =
+    recode_new_outer (flags | RECODE_AUTO_ABORT_FLAG);
   if (!outer)
     abort ();
 
-  /* Set strict mapping.  */
+  /* If using strict mapping, remove fallbacks.  */
 
-  if (strict_mapping)
-    {
-      RECODE_SINGLE single;
-
-      for (single = outer->single_list; single; single = single->next)
-	single->fallback_routine = NULL;
-    }
+  if (outer->strict_mapping)
+    for (RECODE_SINGLE single = outer->single_list;
+         single;
+         single = single->next)
+      single->fallback_routine = NULL;
 
   /* Set the ignored charset.  */
 
@@ -371,7 +373,6 @@ new_request(RECODE_OUTER outer, struct recode_request *request_option)
   request->diacritics_only = request_option->diacritics_only;
   request->diaeresis_char = request_option->diaeresis_char;
   request->make_header_flag = request_option->make_header_flag;
-  request->verbose_flag = request_option->verbose_flag;
   return request;
 }
 
@@ -449,7 +450,7 @@ main (int argc, char *const *argv)
 	exit (EXIT_SUCCESS);
 
       case 'I':
-        request_option.prefer_iconv = true;
+        prefer_iconv = true;
         break;
 
       case 'S':
@@ -493,6 +494,7 @@ main (int argc, char *const *argv)
       case 'f':
 	task_option.fail_level = RECODE_SYSTEM_ERROR;
 	task_option.abort_level = RECODE_USER_ERROR;
+        force_flag = true;
 	break;
 
       case 'g':
@@ -607,8 +609,7 @@ main (int argc, char *const *argv)
 
       case 'v':
 	verbose_flag = true;
-	request_option.verbose_flag = true;
-	break;
+        break;
 
       case 'x':
 	ignored_name = optarg;
@@ -628,7 +629,7 @@ Written by François Pinard <pinard@iro.umontreal.ca>.\n"),
 	     stdout);
       fputs (_("\
 \n\
-Copyright (C) 1990-2022 Free Software Foundation, Inc.\n"),
+Copyright (C) 1990-2023 Free Software Foundation, Inc.\n"),
 	     stdout);
       fputs (_("\
 This is free software; see the source for copying conditions.  There is NO\n\
@@ -646,6 +647,10 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
   if ((ignored_name && *ignored_name == ':')
       || request_option.make_header_flag)
     flags |= RECODE_NO_ICONV_FLAG;
+  if (strict_mapping)
+    flags |= RECODE_STRICT_MAPPING_FLAG;
+  if (force_flag)
+    flags |= RECODE_FORCE_FLAG;
   RECODE_OUTER outer = new_outer (flags);
 
   /* Process charset listing options.  */
@@ -747,7 +752,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
   /* If we are recoding, and we are allowed to use iconv, and --prefer-iconv
      was not used, see if we can do it without iconv.  */
 
-  if ((flags & RECODE_NO_ICONV_FLAG) == 0 && !request_option.prefer_iconv)
+  if ((flags & RECODE_NO_ICONV_FLAG) == 0 && !prefer_iconv)
     {
       RECODE_OUTER no_iconv_outer = new_outer (RECODE_NO_ICONV_FLAG);
       RECODE_REQUEST no_iconv_request =
@@ -762,6 +767,13 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
         }
     }
 
+  /* Scan the request once more to get output if in verbose mode.  */
+  if (verbose_flag)
+    {
+      request->verbose_flag = true;
+      recode_scan_request (request, user_request);
+    }
+
   /* Discard the request argument.  */
   optind++;
 
@@ -847,7 +859,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
 
                   /* Close the file. */
 
-                  if (fclose(task->output.file) == EOF)
+                  if (fclose (task->output.file) == EOF)
                     error (EXIT_FAILURE, errno, "close ()");
 
 		  /* Move the new file over the original.  */
@@ -879,17 +891,23 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
 		  success = false;
 		  if (verbose_flag)
 		    {
-		      fprintf (stderr, _(" failed: %s in step `%s..%s'\n"),
+		      fprintf (stderr, _(" failed: %s%s%s%s%s%s\n"),
 			       task_perror (task),
-			       task->error_at_step->before->name,
-			       task->error_at_step->after->name);
+                               task->error_at_step ? _(" in step `") : "",
+			       task->error_at_step ? task->error_at_step->before->name : "",
+                               task->error_at_step ? _("..") : "",
+			       task->error_at_step ? task->error_at_step->after->name : "",
+                               task->error_at_step ? _("'") : "");
 		      fflush (stderr);
 		    }
 		  else if (!quiet_flag)
-		    error (0, 0, _("%s failed: %s in step `%s..%s'"),
+		    error (0, 0, _("%s failed: %s%s%s%s%s%s"),
 			   input_name, task_perror (task),
-			   task->error_at_step->before->name,
-			   task->error_at_step->after->name);
+                           task->error_at_step ? _(" in step `") : "",
+                           task->error_at_step ? task->error_at_step->before->name : "",
+                           task->error_at_step ? _("..") : "",
+                           task->error_at_step ? task->error_at_step->after->name : "",
+                           task->error_at_step ? _("'") : "");
 
 		  unlink (output_name);
 		}
@@ -905,10 +923,13 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
 	  {
 	    success = false;
 	    if (!quiet_flag)
-	      error (0, 0, _("%s in step `%s..%s'"),
+	      error (0, 0, _("%s%s%s%s%s%s"),
 		     task_perror (task),
-		     task->error_at_step->before->name,
-		     task->error_at_step->after->name);
+                     task->error_at_step ? _(" in step `") : "",
+                     task->error_at_step ? task->error_at_step->before->name : "",
+                     task->error_at_step ? _("..") : "",
+                     task->error_at_step ? task->error_at_step->after->name : "",
+                     task->error_at_step ? _("'") : "");
 	  }
       }
   }
