@@ -1,6 +1,6 @@
 /* Vietnamese charset processing.
-   Copyright  1999, 2000 Progiciels Bourbeau-Pinard inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1999.
+   Copyright © 1999-2018 Progiciels Bourbeau-Pinard inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1999.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
@@ -298,145 +298,142 @@ static const unsigned short viscii_viqr_data[] =
     DONE
   };
 
-#define u(Character) ((unsigned char) (Character))
-/* FIXME: Should not use Latin-1 characters, anyway.  */
-
 static const unsigned short viscii_vni_data[] =
   {
-    2, u('A'), u(''), DONE,
-    5, u('A'), u(''), DONE,
-    6, u('A'), u(''), DONE,
-    20, u('Y'), u(''), DONE,
-    25, u('Y'), u(''), DONE,
-    30, u(''), DONE,
-    128, u('A'), u(''), DONE,
-    129, u('A'), u(''), DONE,
-    130, u('A'), u(''), DONE,
-    131, u('A'), u(''), DONE,
-    132, u('A'), u(''), DONE,
-    133, u('A'), u(''), DONE,
-    134, u('A'), u(''), DONE,
-    135, u('A'), u(''), DONE,
-    136, u('E'), u(''), DONE,
-    137, u('E'), u(''), DONE,
-    138, u('E'), u(''), DONE,
-    139, u('E'), u(''), DONE,
-    140, u('E'), u(''), DONE,
-    141, u('E'), u(''), DONE,
-    142, u('E'), u(''), DONE,
-    143, u('O'), u(''), DONE,
-    144, u('O'), u(''), DONE,
-    145, u('O'), u(''), DONE,
-    146, u('O'), u(''), DONE,
-    147, u('O'), u(''), DONE,
-    148, u(''), u(''), DONE,
-    149, u(''), u(''), DONE,
-    150, u(''), u(''), DONE,
-    151, u(''), u(''), DONE,
-    152, u(''), DONE,
-    153, u('O'), u(''), DONE,
-    154, u('O'), u(''), DONE,
-    155, u(''), DONE,
-    156, u('U'), u(''), DONE,
-    157, u('U'), u(''), DONE,
-    158, u('U'), u(''), DONE,
-    159, u('Y'), u(''), DONE,
-    160, u('O'), u(''), DONE,
-    161, u('a'), u(''), DONE,
-    162, u('a'), u(''), DONE,
-    163, u('a'), u(''), DONE,
-    164, u('a'), u(''), DONE,
-    165, u('a'), u(''), DONE,
-    166, u('a'), u(''), DONE,
-    167, u('a'), u(''), DONE,
-    168, u('e'), u(''), DONE,
-    169, u('e'), u(''), DONE,
-    170, u('e'), u(''), DONE,
-    171, u('e'), u(''), DONE,
-    172, u('e'), u(''), DONE,
-    173, u('e'), u(''), DONE,
-    174, u('e'), u(''), DONE,
-    175, u('o'), u(''), DONE,
-    176, u('o'), u(''), DONE,
-    177, u('o'), u(''), DONE,
-    178, u('o'), u(''), DONE,
-    179, u(''), u(''), DONE,
-    180, u(''), DONE,
-    181, u('o'), u(''), DONE,
-    182, u(''), u(''), DONE,
-    183, u(''), u(''), DONE,
-    184, u(''), DONE,
-    185, u(''), u(''), DONE,
-    186, u(''), u(''), DONE,
-    187, u(''), u(''), DONE,
-    188, u(''), u(''), DONE,
-    189, u(''), DONE,
-    190, u(''), u(''), DONE,
-    191, u(''), DONE,
-    192, u('A'), u(''), DONE,
-    193, u('A'), u(''), DONE,
-    194, u('A'), u(''), DONE,
-    195, u('A'), u(''), DONE,
-    196, u('A'), u(''), DONE,
-    197, u('A'), u(''), DONE,
-    198, u('a'), u(''), DONE,
-    199, u('a'), u(''), DONE,
-    200, u('E'), u(''), DONE,
-    201, u('E'), u(''), DONE,
-    202, u('E'), u(''), DONE,
-    203, u('E'), u(''), DONE,
-    204, u(''), DONE,
-    205, u(''), DONE,
-    206, u(''), DONE,
-    207, u('y'), u(''), DONE,
-    208, u(''), DONE,
-    209, u(''), u(''), DONE,
-    210, u('O'), u(''), DONE,
-    211, u('O'), u(''), DONE,
-    212, u('O'), u(''), DONE,
-    213, u('a'), u(''), DONE,
-    214, u('y'), u(''), DONE,
-    215, u(''), u(''), DONE,
-    216, u(''), u(''), DONE,
-    217, u('U'), u(''), DONE,
-    218, u('U'), u(''), DONE,
-    219, u('y'), u(''), DONE,
-    220, u(''), DONE,
-    221, u('Y'), u(''), DONE,
-    222, u(''), u(''), DONE,
-    223, u(''), DONE,
-    224, u('a'), u(''), DONE,
-    225, u('a'), u(''), DONE,
-    226, u('a'), u(''), DONE,
-    227, u('a'), u(''), DONE,
-    228, u('a'), u(''), DONE,
-    229, u('a'), u(''), DONE,
-    230, u(''), u(''), DONE,
-    231, u('a'), u(''), DONE,
-    232, u('e'), u(''), DONE,
-    233, u('e'), u(''), DONE,
-    234, u('e'), u(''), DONE,
-    235, u('e'), u(''), DONE,
-    236, u(''), DONE,
-    237, u(''), DONE,
-    238, u(''), DONE,
-    239, u(''), DONE,
-    240, u(''), DONE,
-    241, u(''), u(''), DONE,
-    242, u('o'), u(''), DONE,
-    243, u('o'), u(''), DONE,
-    244, u('o'), u(''), DONE,
-    245, u('o'), u(''), DONE,
-    246, u('o'), u(''), DONE,
-    247, u('o'), u(''), DONE,
-    248, u('u'), u(''), DONE,
-    249, u('u'), u(''), DONE,
-    250, u('u'), u(''), DONE,
-    251, u('u'), u(''), DONE,
-    252, u('u'), u(''), DONE,
-    253, u('y'), u(''), DONE,
-    254, u(''), u(''), DONE,
-    255, u(''), u(''), DONE,
+    2, 'A', 0xDA, DONE,
+    5, 'A', 0xDC, DONE,
+    6, 'A', 0xC3, DONE,
+    20, 'Y', 0xDB, DONE,
+    25, 'Y', 0xD5, DONE,
+    30, 0xCE, DONE,
+    128, 'A', 0xCF, DONE,
+    129, 'A', 0xC8, DONE,
+    130, 'A', 0xC9, DONE,
+    131, 'A', 0xCB, DONE,
+    132, 'A', 0xC1, DONE,
+    133, 'A', 0xC0, DONE,
+    134, 'A', 0xC5, DONE,
+    135, 'A', 0xC4, DONE,
+    136, 'E', 0xD5, DONE,
+    137, 'E', 0xCF, DONE,
+    138, 'E', 0xC1, DONE,
+    139, 'E', 0xC0, DONE,
+    140, 'E', 0xC5, DONE,
+    141, 'E', 0xC3, DONE,
+    142, 'E', 0xC4, DONE,
+    143, 'O', 0xC1, DONE,
+    144, 'O', 0xC0, DONE,
+    145, 'O', 0xC5, DONE,
+    146, 'O', 0xC3, DONE,
+    147, 'O', 0xC4, DONE,
+    148, 0xD4, 0xCF, DONE,
+    149, 0xD4, 0xD9, DONE,
+    150, 0xD4, 0xD8, DONE,
+    151, 0xD4, 0xDB, DONE,
+    152, 0xD2, DONE,
+    153, 'O', 0xDB, DONE,
+    154, 'O', 0xCF, DONE,
+    155, 0xC6, DONE,
+    156, 'U', 0xDB, DONE,
+    157, 'U', 0xD5, DONE,
+    158, 'U', 0xCF, DONE,
+    159, 'Y', 0xD8, DONE,
+    160, 'O', 0xD5, DONE,
+    161, 'a', 0xE9, DONE,
+    162, 'a', 0xE8, DONE,
+    163, 'a', 0xEB, DONE,
+    164, 'a', 0xE1, DONE,
+    165, 'a', 0xE0, DONE,
+    166, 'a', 0xE5, DONE,
+    167, 'a', 0xE4, DONE,
+    168, 'e', 0xF5, DONE,
+    169, 'e', 0xEF, DONE,
+    170, 'e', 0xE1, DONE,
+    171, 'e', 0xE0, DONE,
+    172, 'e', 0xE5, DONE,
+    173, 'e', 0xE3, DONE,
+    174, 'e', 0xE4, DONE,
+    175, 'o', 0xE1, DONE,
+    176, 'o', 0xE0, DONE,
+    177, 'o', 0xE5, DONE,
+    178, 'o', 0xE3, DONE,
+    179, 0xD4, 0xD5, DONE,
+    180, 0xD4, DONE,
+    181, 'o', 0xE4, DONE,
+    182, 0xF4, 0xF8, DONE,
+    183, 0xF4, 0xFB, DONE,
+    184, 0xF2, DONE,
+    185, 0xD6, 0xCF, DONE,
+    186, 0xD6, 0xD9, DONE,
+    187, 0xD6, 0xD8, DONE,
+    188, 0xD6, 0xDB, DONE,
+    189, 0xF4, DONE,
+    190, 0xF4, 0xF9, DONE,
+    191, 0xD6, DONE,
+    192, 'A', 0xD8, DONE,
+    193, 'A', 0xD9, DONE,
+    194, 'A', 0xC2, DONE,
+    195, 'A', 0xD5, DONE,
+    196, 'A', 0xDB, DONE,
+    197, 'A', 0xCA, DONE,
+    198, 'a', 0xFA, DONE,
+    199, 'a', 0xFC, DONE,
+    200, 'E', 0xD8, DONE,
+    201, 'E', 0xD9, DONE,
+    202, 'E', 0xC2, DONE,
+    203, 'E', 0xDB, DONE,
+    204, 0xCC, DONE,
+    205, 0xCD, DONE,
+    206, 0xD3, DONE,
+    207, 'y', 0xF8, DONE,
+    208, 0xD1, DONE,
+    209, 0xF6, 0xF9, DONE,
+    210, 'O', 0xD8, DONE,
+    211, 'O', 0xD9, DONE,
+    212, 'O', 0xC2, DONE,
+    213, 'a', 0xEF, DONE,
+    214, 'y', 0xFB, DONE,
+    215, 0xF6, 0xF8, DONE,
+    216, 0xF6, 0xFB, DONE,
+    217, 'U', 0xD8, DONE,
+    218, 'U', 0xD9, DONE,
+    219, 'y', 0xF5, DONE,
+    220, 0xEE, DONE,
+    221, 'Y', 0xD9, DONE,
+    222, 0xF4, 0xF5, DONE,
+    223, 0xF6, DONE,
+    224, 'a', 0xF8, DONE,
+    225, 'a', 0xF9, DONE,
+    226, 'a', 0xE2, DONE,
+    227, 'a', 0xF5, DONE,
+    228, 'a', 0xFB, DONE,
+    229, 'a', 0xEA, DONE,
+    230, 0xF6, 0xF5, DONE,
+    231, 'a', 0xE3, DONE,
+    232, 'e', 0xF8, DONE,
+    233, 'e', 0xF9, DONE,
+    234, 'e', 0xE2, DONE,
+    235, 'e', 0xFB, DONE,
+    236, 0xEC, DONE,
+    237, 0xED, DONE,
+    238, 0xF3, DONE,
+    239, 0xE6, DONE,
+    240, 0xF1, DONE,
+    241, 0xF6, 0xEF, DONE,
+    242, 'o', 0xF8, DONE,
+    243, 'o', 0xF9, DONE,
+    244, 'o', 0xE2, DONE,
+    245, 'o', 0xF5, DONE,
+    246, 'o', 0xFB, DONE,
+    247, 'o', 0xEF, DONE,
+    248, 'u', 0xEF, DONE,
+    249, 'u', 0xF8, DONE,
+    250, 'u', 0xF9, DONE,
+    251, 'u', 0xF5, DONE,
+    252, 'u', 0xFB, DONE,
+    253, 'y', 0xF9, DONE,
+    254, 0xF4, 0xEF, DONE,
+    255, 0xD6, 0xD5, DONE,
     DONE
   };
 
@@ -457,6 +454,6 @@ module_vietnamese (RECODE_OUTER outer)
 }
 
 void
-delmodule_vietnamese (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_vietnamese (_GL_UNUSED RECODE_OUTER outer)
 {
 }
